function [status, status_description, timeout_setting] = agt_getVisaTimeout(connection)
% PSG/ESG Download Assistant, Version 2.0
% Copyright (C) 2005 Agilent Technologies, Inc.
%
% function [status, status_description] = agt_getVisaTimeout(connection)
% The function gets the timeout setting of instrument connection.
%
% Output:        
%   status                  integer     status of agt_getVisaTimeout. 0:succeeded, -1:failed
%   status_description      string      if status is < 0, status_description contains an error message.
%   timeout_setting	        integer     if status is 0, timeout_setting is valid.
% Input:
%   connection    a structure generated by the agt_newconnection function.
%
response = connection.Timeout;
statusString = query(connection,'SYSTEM:ERROR?');

if strcmpi(statusString,['+0,"No error"' char(10)])
    status = 0;
else
    status = -1;
end

if (status <0) 
   status_description = statusString;
   timeout_setting = [];
else
   status_description = 'succeeded';
   timeout_setting = response;
end
